Structs
- Capability
Report - Capability check result with the capability that was checked.
Enums
- Capability
Status - Status of a platform capability check.
- Platform
Capability - Platform-specific capabilities for transparent proxy and Unix socket support.
Functions
- check_
capability - Check the status of a specific platform capability by probing the system.
- check_
capability_ with_ overrides - Check a platform capability, consulting an overrides map first.
- format_
capability_ report - Format a list of capability reports as a human-readable diagnostic string.
- missing_
capabilities - Filter reports to only those that are not available, for startup warnings.
- platform_
info - Return a summary of all platform capabilities and their statuses.
- platform_
info_ with_ overrides - Return a summary using provided overrides for specified capabilities.