pub fn check_capability(cap: PlatformCapability) -> CapabilityStatusExpand description
Check the status of a specific platform capability by probing the system.
pub fn check_capability(cap: PlatformCapability) -> CapabilityStatusCheck the status of a specific platform capability by probing the system.