Module platform

Module platform 

Structs

CapabilityReport
Capability check result with the capability that was checked.

Enums

CapabilityStatus
Status of a platform capability check.
PlatformCapability
Platform-specific capabilities for transparent proxy and Unix socket support.

Functions

check_capability
Check the status of a specific platform capability by probing the system.
check_capability_with_overrides
Check a platform capability, consulting an overrides map first.
format_capability_report
Format a list of capability reports as a human-readable diagnostic string.
missing_capabilities
Filter reports to only those that are not available, for startup warnings.
platform_info
Return a summary of all platform capabilities and their statuses.
platform_info_with_overrides
Return a summary using provided overrides for specified capabilities.